@@ -28,18 +28,21 @@ class RabbitMQ:
 class BasicQueueConsumer():
 
     queue_name = None
-    prefetch_size = None
+    arguments = None
     exchanges = []
 
     def __init__(self, queue_name, exchanges=None, prefetch_size=None,
+                 arguments=None,
                  *args, **kwargs):
         super().__init__(*args, **kwargs)
         rabbitmq = RabbitMQ()
         self.connection = rabbitmq.connect()
         self.channel = self.connection.channel()
+        if prefetch_size is not None:
+            self.channel.basic_qos(prefetch_count=prefetch_size)
         self.queue_name = queue_name
+        self.arguments = arguments
         self.exchanges = exchanges
-        self.prefetch_size = prefetch_size
 
     def __bind_queue(self):
         for ex in self.exchanges:
@@ -54,14 +57,12 @@ class BasicQueueConsumer():
                                     routing_key=rounting_key)
 
     def declare_and_consume(self, callback):
-        self.channel.queue_declare(queue=self.queue_name, durable=True)
+        self.channel.queue_declare(queue=self.queue_name, durable=True,
+                                   arguments=self.arguments)
         self.channel.basic_consume(queue=self.queue_name, auto_ack=False,
                                    on_message_callback=callback)
         self.__bind_queue()
 
-        if self.prefetch_size is not None:
-            self.channel.basic_qos(prefetch_count=self.prefetch_size)
-
         self.channel.start_consuming()
 
     def close(self):
@@ -69,6 +70,13 @@ class BasicQueueConsumer():
         self.channel.close()
         self.connection.close()
 
+    def count_rejects_this_message(self, properties):
+        count = 0
+        xdeath = properties.headers.get('x-death', [])
+        if len(xdeath) > 0:
+            count = xdeath[0].get('count', 0)
+        return count
+
 
 class ProducerQueue:
 
